@@ -1,3 +1,5 @@
+package Amazon::Site;
+
 =head1 NAME
 
 Amazon::Site - A class to represent an Amazon site
@@ -21,6 +23,9 @@ Amazon::Site - A class to represent an Amazon site
 
 use Feature::Compat::Class;
 
+use feature 'signatures';
+no warnings 'experimental::signatures';
+
 class Amazon::Site {
   field $code :param;
   field $country :param;
